
## CATO-CLI - mutation.site.removeBgpPeer:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.site.removeBgpPeer) for documentation on this operation.

### Usage for mutation.site.removeBgpPeer:

```bash
catocli mutation site removeBgpPeer -h

catocli mutation site removeBgpPeer <json>

catocli mutation site removeBgpPeer --json-file mutation.site.removeBgpPeer.json

catocli mutation site removeBgpPeer '{"removeBgpPeerInput":{"id":"id"}}'

catocli mutation site removeBgpPeer '{
    "removeBgpPeerInput": {
        "id": "id"
    }
}'
```

#### Operation Arguments for mutation.site.removeBgpPeer ####

`accountId` [ID] - (required) N/A    
`removeBgpPeerInput` [RemoveBgpPeerInput] - (required) N/A    
